<img width="150" align="left" style="float: left; margin: 0 10px 0 0;" alt="Torch γ logo" src="assets/torch-gamma.png">   

# Torch γ

Torch γ is a framework for building and training neural networks inspired by [Ruby](https://www.cs.ox.ac.uk/people/geraint.jones/ruby/).

Torch Gamma intends to use relational algebra to build and train neural networks.

## About Ruby

<img width="100" align="left" style="float: left; margin: 0 10px 0 0;" alt="Ruby logo" src="assets/ruby.png">  

Ruby is a programming language that is designed as an HDL (Hardware Description Language).

